'use strict';

const types = [
  {
    value: "feat",
    get name() {
      return `feat:      ${this.emoji} \u65B0\u589E\u529F\u80FD | A new feature`;
    },
    emoji: "\u2728"
  },
  {
    value: "fix",
    get name() {
      return `fix:       ${this.emoji} \u4FEE\u590D\u7F3A\u9677 | A bug fix`;
    },
    emoji: "\u{1F41B}"
  },
  {
    value: "docs",
    get name() {
      return `docs:      ${this.emoji} \u6587\u6863\u66F4\u65B0 | Documentation only changes`;
    },
    emoji: "\u{1F4DD}"
  },
  {
    value: "style",
    get name() {
      return `style:     ${this.emoji} \u4EE3\u7801\u683C\u5F0F | Changes that do not affect the meaning of the code`;
    },
    emoji: "\u{1F484}"
  },
  {
    value: "refactor",
    get name() {
      return `refactor:  ${this.emoji} \u4EE3\u7801\u91CD\u6784 | A code change that neither fixes a bug nor adds a feature`;
    },
    emoji: "\u{1F9B4}"
  },
  {
    value: "perf",
    get name() {
      return `perf:      ${this.emoji} \u6027\u80FD\u63D0\u5347 | A code change that improves performance`;
    },
    emoji: "\u26A1\uFE0F"
  },
  {
    value: "test",
    get name() {
      return `test:      ${this.emoji} \u6D4B\u8BD5\u76F8\u5173 | Adding missing tests or correcting existing tests`;
    },
    emoji: "\u2705"
  },
  {
    value: "build",
    get name() {
      return `build:     ${this.emoji} \u6784\u5EFA\u76F8\u5173 | Changes that affect the build system or external dependencies`;
    },
    emoji: "\u{1F4E6}\uFE0F"
  },
  {
    value: "ci",
    get name() {
      return `ci:        ${this.emoji} \u6301\u7EED\u96C6\u6210 | Changes to our CI configuration files and scripts`;
    },
    emoji: "\u{1F3A1}"
  },
  {
    value: "revert",
    get name() {
      return `revert:    ${this.emoji} \u56DE\u9000\u4EE3\u7801 | Revert to a commit`;
    },
    emoji: "\u{1F528}"
  },
  {
    value: "chore",
    get name() {
      return `chore:     ${this.emoji} \u5176\u4ED6\u4FEE\u6539 | Other changes that do not modify src or test files`;
    },
    emoji: "\u23EA\uFE0F"
  }
];
const typeEnum = types.map(({ value }) => value);
const messages = {
  type: "\u9009\u62E9\u4F60\u8981\u63D0\u4EA4\u7684\u7C7B\u578B :",
  scope: "\u9009\u62E9\u4E00\u4E2A\u63D0\u4EA4\u8303\u56F4\uFF08\u53EF\u9009\uFF09:",
  customScope: "\u8BF7\u8F93\u5165\u81EA\u5B9A\u4E49\u7684\u63D0\u4EA4\u8303\u56F4 :",
  subject: "\u586B\u5199\u7B80\u77ED\u7CBE\u70BC\u7684\u53D8\u66F4\u63CF\u8FF0 :\n",
  body: '\u586B\u5199\u66F4\u52A0\u8BE6\u7EC6\u7684\u53D8\u66F4\u63CF\u8FF0\uFF08\u53EF\u9009\uFF09\u3002\u4F7F\u7528 "|" \u6362\u884C :\n',
  breaking: '\u5217\u4E3E\u975E\u517C\u5BB9\u6027\u91CD\u5927\u7684\u53D8\u66F4\uFF08\u53EF\u9009\uFF09\u3002\u4F7F\u7528 "|" \u6362\u884C :\n',
  footerPrefixesSelect: "\u9009\u62E9\u5173\u8054issue\u524D\u7F00\uFF08\u53EF\u9009\uFF09:",
  customFooterPrefix: "\u8F93\u5165\u81EA\u5B9A\u4E49issue\u524D\u7F00 :",
  footer: "\u5217\u4E3E\u5173\u8054issue (\u53EF\u9009) \u4F8B\u5982: #31, #I3244 :\n",
  confirmCommit: "\u662F\u5426\u63D0\u4EA4\u6216\u4FEE\u6539commit ?"
};
const index = {
  extends: [
    "@commitlint/config-conventional"
  ],
  rules: {
    // @see: https://commitlint.js.org/#/reference-rules
    "type-enum": [
      2,
      "always",
      typeEnum
    ]
  },
  prompt: {
    alias: {
      fd: "docs: fix typos"
    },
    messages,
    types,
    useEmoji: true,
    emojiAlign: "center",
    themeColorCode: "",
    scopes: [],
    allowCustomScopes: true,
    allowEmptyScopes: true,
    customScopesAlign: "bottom",
    customScopesAlias: "custom",
    emptyScopesAlias: "empty",
    upperCaseSubject: false,
    markBreakingChangeMode: false,
    allowBreakingChanges: ["feat", "fix"],
    breaklineNumber: 100,
    breaklineChar: "|",
    skipQuestions: [],
    issuePrefixes: [
      // 如果使用 gitee 作为开发管理
      { value: "link", name: "link:     \u94FE\u63A5 ISSUES \u8FDB\u884C\u4E2D" },
      { value: "closed", name: "closed:   \u6807\u8BB0 ISSUES \u5DF2\u5B8C\u6210" }
    ],
    customIssuePrefixAlign: "top",
    emptyIssuePrefixAlias: "skip",
    customIssuePrefixAlias: "custom",
    allowCustomIssuePrefix: true,
    allowEmptyIssuePrefix: true,
    confirmColorize: true,
    maxHeaderLength: Infinity,
    maxSubjectLength: Infinity,
    minSubjectLength: 0,
    scopeOverrides: void 0,
    defaultBody: "",
    defaultIssues: "",
    defaultScope: "",
    defaultSubject: ""
  }
};

module.exports = index;
